@@ -2,9 +2,9 @@ use strict;
 use warnings;
 
 package Sub::Import;
-our $VERSION = '0.092801';
-
-
+BEGIN {
+  $Sub::Import::VERSION = '1.000';
+}
 # ABSTRACT: import routines from most anything using Sub::Exporter
 
 use B qw(svref_2object);
@@ -119,9 +119,9 @@ sub _create_methods_exporter {
 
   no strict 'refs';
 
-  my @ok      = @{ $target . "::EXPORT_OK"  };
-  my @default = @{ $target . "::EXPORT"     };
-  my %groups  = %{ $target . "::EXPORT_TAG" };
+  my @ok      = @{ $target . "::EXPORT_OK"   };
+  my @default = @{ $target . "::EXPORT"      };
+  my %groups  = %{ $target . "::EXPORT_TAGS" };
 
   $self->__filter_subs($_) for (\@ok, \@default, values %groups);
 
@@ -155,7 +155,6 @@ sub _create_methods_fallback {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -164,7 +163,7 @@ Sub::Import - import routines from most anything using Sub::Exporter
 
 =head1 VERSION
 
-version 0.092801
+version 1.000
 
 =head1 SYNOPSIS
 
@@ -200,15 +199,14 @@ anyone miss them?)
 
 =head1 AUTHOR
 
-  Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
